@@ -1,5 +1,5 @@
 package Tree::RB::XS;
-$Tree::RB::XS::VERSION = '0.15';
+$Tree::RB::XS::VERSION = '0.16';
 # VERSION
 # ABSTRACT: Red/Black Tree and LRU Cache implemented in C
 
@@ -25,9 +25,9 @@ our %EXPORT_TAGS= (
 );
 
 if ($] < 5.016) {
-   # Before 5.16, XS can't call CORE::fc,
-   # and before 5.14 fc didn't exist so the best we can do is 'lc'
-   eval($] >= 5.014? 'sub _fc_impl { fc shift }' : 'sub _fc_impl { lc shift }');
+   # Before 5.16, perl didn't have 'fc' and also XS can't call CORE::lc
+   eval('sub _fc_impl { lc shift } 1')
+      or die $@;
 }
 
 
@@ -218,6 +218,15 @@ LRU Cache feature:
   $tree->iter_older->next_keys(1e99);    # (1,2,3)
   @removed= $tree->truncate_recent(2);   # returns (3), leaves (2,1) in tree
 
+Case-folding tied hashes:
+
+  my %hash;
+  tie %hash, 'Tree::RB::XS', 'foldcase';
+  $hash{'content-type'}= 'text/plain';
+  $hash{'Content-Type'}= 'text/html';
+  say $hash{'content-type'}; # text/html
+  say keys %hash;            # Content-Type
+
 Fancy iterators:
 
   # iterator has 'current position'. inspect it, then step
@@ -277,6 +286,10 @@ Option to allow L<duplicate keys|/allow_duplicates> while preserving insertion o
 
 =item *
 
+Option to case-fold keys for comparisons while preserving the original key.
+
+=item *
+
 Optional linked-list of L<"recent" order|/track_recent>, to facilitate LRU or MRU caches.
 
 =back
@@ -367,14 +380,14 @@ assembled tree.  The list does not need to include all the nodes.
 Specifies the function that compares keys.  Read-only; pass as an option to
 the constructor.
 
-This is one of: L</CMP_PERL> (default), L</CMP_INT>, L</CMP_FLOAT>, L</CMP_MEMCMP>,
-L</CMP_STR>, L</CMP_FOLDCASE>, L</CMP_NUMSPLIT>, L</CMP_NUMSPLIT_FOLDCASE> or a coderef.
+This is one of: L</CMP_PERL> (default), L</CMP_INT>, L</CMP_FLOAT>, L</CMP_STR>, L</CMP_MEMCMP>,
+L</CMP_FOLDCASE>, L</CMP_NUMSPLIT>, L</CMP_NUMSPLIT_FOLDCASE> or a coderef.
 C<CMP_INT> and C<CMP_FLOAT> are the most efficient, and internally store the key as a number.
-C<CMP_MEMCMP> and C<CMP_STR> copy the key into an internal buffer, and offer moderate speed
-gains over C<CMP_PERL>.  C<CMP_PERL> is Perl's own C<cmp> operator.  C<CMP_FOLDCASE> is for
-case-insensitive sorting (applies 'fc' to the keys before comparing) and C<CMP_NUMSPLIT> is
-a "natural sort" that compares numeric segments of the key as numbers while comparing the rest
-as a string.  It also has a 'fc' variant.
+C<CMP_STR> and C<CMP_MEMCMP> copy the key into an internal buffer, and offer moderate speed
+gains over C<CMP_PERL>.  C<CMP_PERL> is Perl's own C<cmp> operator, which may handle objects
+with overloaded comparisons.  C<CMP_FOLDCASE> is for case-insensitive sorting (applies 'fc' to
+the keys before comparing) and C<CMP_NUMSPLIT> is a "natural sort" that compares numeric
+segments of the key as numbers while comparing the rest as a string.  It also has a 'fc' variant.
 
 If set to a coderef, it should take two parameters and return an integer
 indicating their order in the same manner as Perl's C<cmp>.
@@ -1109,11 +1122,19 @@ benchmarks quite a bit faster.
 
 The fastest pure-perl module on CPAN for ordered hashes / LRU caches.
 
+=item L<Tie::CPHash>
+
+This module lets you tie a hash so that hash keys become case-insensitive, but also preserve
+the case of the most recent 'put' operation.  This is a pure-perl implementation that is fairly
+fast and minimal.  Tree::RB::XS can do the same a bit faster with:
+
+  tie %hash, 'Tree::RB::XS', compare_fn => 'foldcase';
+
 =back
 
 =head1 VERSION
 
-version 0.15
+version 0.16
 
 =head1 AUTHOR
 
